@@ -557,13 +557,15 @@ func (c *AppDocsCommand) builtinMDX(args []string) int {
 			// If we have a plugin.Instance then we can extract other information
 			// from this plugin. We accept pure factories too that don't return
 			// this so we type-check here.
+			cleanup := func() {}
 			if pinst, ok := raw.(*plugin.Instance); ok {
 				raw = pinst.Component
-				defer pinst.Close()
+				cleanup = pinst.Close // must cleanup during this loop to avoid instantiating all plugins simultaneously
 			}
 
 			doc, err := component.Documentation(raw)
 			if err != nil {
+				cleanup()
 				panic(err.Error())
 			}
 
@@ -574,6 +576,7 @@ func (c *AppDocsCommand) builtinMDX(args []string) int {
 			default:
 				c.mdxFormat(t, f.t, doc)
 			}
+			cleanup()
 		}
 	}
 
