@@ -3,6 +3,7 @@ package cli
 import (
 	"context"
 	"errors"
+	stdflag "flag"
 	"io"
 	"path/filepath"
 	"regexp"
@@ -154,6 +155,12 @@ func (c *baseCommand) Init(opts ...Option) error {
 	}
 	c.args = baseCfg.Flags.Args()
 
+	// Check for flags after args
+	if err := checkFlagsAfterArgs(c.args, baseCfg.Flags); err != nil {
+		c.ui.Output(clierrors.Humanize(err), terminal.WithErrorStyle())
+		return err
+	}
+
 	// Reset the UI to plain if that was set
 	if c.flagPlain {
 		c.ui = terminal.NonInteractiveUI(c.Ctx)
@@ -438,6 +445,79 @@ func (c *baseCommand) flagSet(bit flagSetBit, f func(*flag.Sets)) *flag.Sets {
 	return set
 }
 
+// checkFlagsAfterArgs checks for a very common user error scenario where
+// CLI flags are specified after positional arguments. Since we use the
+// stdlib flag package, this is not allowed. However, we can detect this
+// scenario, and notify a user. We can't easily automatically fix it because
+// its hard to tell positional vs intentional flags.
+func checkFlagsAfterArgs(args []string, set *flag.Sets) error {
+	if len(args) == 0 {
+		return nil
+	}
+
+	// Build up our arg map for easy searching.
+	flagMap := map[string]struct{}{}
+	for _, v := range args {
+		// If we reach a "--" we're done. This is a common designator
+		// in CLIs (such as exec) that everything following is fair game.
+		if v == "--" {
+			break
+		}
+
+		// There is always at least 2 chars in a flag "-v" example.
+		if len(v) < 2 {
+			continue
+		}
+
+		// Flags start with a hyphen
+		if v[0] != '-' {
+			continue
+		}
+
+		// Detect double hyphen flags too
+		if v[1] == '-' {
+			v = v[1:]
+		}
+
+		// More than double hyphen, ignore. note this looks like we can
+		// go out of bounds and panic cause this is the 3rd char if we have
+		// a double hyphen and we only protect on 2, but since we check first
+		// against plain "--" we know that its not exactly "--" AND the length
+		// is at least 2, meaning we can safely imply we have length 3+ for
+		// double-hyphen prefixed values.
+		if v[1] == '-' {
+			continue
+		}
+
+		// If we have = for "-foo=bar", trim out the =.
+		if idx := strings.Index(v, "="); idx >= 0 {
+			v = v[:idx]
+		}
+
+		flagMap[v[1:]] = struct{}{}
+	}
+
+	// Now look for anything that looks like a flag we accept. We only
+	// look for flags we accept because that is the most common error and
+	// limits the false positives we'll get on arguments that want to be
+	// hyphen-prefixed.
+	didIt := false
+	set.VisitSets(func(name string, s *flag.Set) {
+		s.VisitAll(func(f *stdflag.Flag) {
+			if _, ok := flagMap[f.Name]; ok {
+				// Uh oh, we done it. We put a flag after an arg.
+				didIt = true
+			}
+		})
+	})
+
+	if didIt {
+		return errFlagAfterArgs
+	}
+
+	return nil
+}
+
 // flagSetBit is used with baseCommand.flagSet
 type flagSetBit uint
 
@@ -451,6 +531,17 @@ var (
 	// ErrSentinel is a sentinel value that we can return from Init to force an exit.
 	ErrSentinel = errors.New("error sentinel")
 
+	errFlagAfterArgs = errors.New(strings.TrimSpace(`
+Flags must be specified before positional arguments in the CLI command.
+For example "waypoint up -example project" not "waypoint up project -example".
+Please reorder your arguments and try again.
+
+Note: we can't automatically fix this or allow this since we can't safely
+detect what you want as flag arguments and what you want as positional arguments.
+The underlying library we use for flag parsing (the Go standard library)
+enforces this requirement. Sorry!
+`))
+
 	errAppModeSingle = strings.TrimSpace(`
 This command requires a single targeted app. You have multiple apps defined
 so you can specify the app to target using the "-app" flag.
