@@ -57,10 +57,12 @@ func (a *App) Release(ctx context.Context, target *pb.Deployment) (
 			"err", err)
 	}
 
+	unimplemeneted := false
 	c, err := a.createReleaser(ctx, &evalCtx)
 	if status.Code(err) == codes.Unimplemented {
 		c = nil
 		err = nil
+		unimplemeneted = true
 	}
 	if err != nil {
 		return nil, nil, err
@@ -75,6 +77,12 @@ func (a *App) Release(ctx context.Context, target *pb.Deployment) (
 		return nil, nil, err
 	}
 
+	if releasepb != nil {
+		rpb := releasepb.(*pb.Release)
+		rpb.Unimplemented = unimplemeneted
+		releasepb = rpb
+	}
+
 	var release component.Release
 	if result != nil {
 		release = result.(component.Release)
