@@ -2,16 +2,22 @@ package runner
 
 import (
 	"context"
+	"encoding/json"
 	"fmt"
 	"io/ioutil"
+	"net"
+	"os"
 	"path/filepath"
 	"reflect"
+	"strings"
 
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/go-multierror"
+	goplugin "github.com/hashicorp/go-plugin"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 
+	sdk "github.com/hashicorp/waypoint-plugin-sdk"
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint-plugin-sdk/datadir"
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
@@ -225,12 +231,33 @@ func (r *Runner) pluginFactories(
 	}
 	log.Debug("plugin search path", "path", pluginPaths)
 
+	// Look for any reattach plugins
+	var reattachPluginConfigs map[string]*goplugin.ReattachConfig
+	reattachPluginsStr := os.Getenv("WP_REATTACH_PLUGINS")
+	if reattachPluginsStr != "" {
+		var err error
+		reattachPluginConfigs, err = parseReattachPlugins(reattachPluginsStr)
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	// Search for all of our plugins
 	var perr error
 	for _, pluginCfg := range plugins {
 		plog := log.With("plugin_name", pluginCfg.Name)
 		plog.Debug("searching for plugin")
 
+		if reattachConfig, ok := reattachPluginConfigs[pluginCfg.Name]; ok {
+			plog.Debug(fmt.Sprintf("plugin %s is declared as running for reattachment", pluginCfg.Name))
+			for _, t := range pluginCfg.Types() {
+				if err := result[t].Register(pluginCfg.Name, plugin.ReattachPluginFactory(reattachConfig, t)); err != nil {
+					return nil, err
+				}
+			}
+			continue
+		}
+
 		// Find our plugin.
 		cmd, err := plugin.Discover(pluginCfg, pluginPaths)
 		if err != nil {
@@ -267,6 +294,46 @@ func (r *Runner) pluginFactories(
 	return result, perr
 }
 
+// parse information on reattaching to plugins out of a
+// JSON-encoded environment variable.
+func parseReattachPlugins(in string) (map[string]*goplugin.ReattachConfig, error) {
+	reattachConfigs := map[string]*goplugin.ReattachConfig{}
+	if in != "" {
+		in = strings.TrimRight(in, "'")
+		in = strings.TrimLeft(in, "'")
+		var m map[string]sdk.ReattachConfig
+		err := json.Unmarshal([]byte(in), &m)
+		if err != nil {
+			return reattachConfigs, fmt.Errorf("Invalid format for WP_REATTACH_PROVIDERS: %w", err)
+		}
+		for p, c := range m {
+			var addr net.Addr
+			switch c.Addr.Network {
+			case "unix":
+				addr, err = net.ResolveUnixAddr("unix", c.Addr.String)
+				if err != nil {
+					return reattachConfigs, fmt.Errorf("Invalid unix socket path %q for %q: %w", c.Addr.String, p, err)
+				}
+			case "tcp":
+				addr, err = net.ResolveTCPAddr("tcp", c.Addr.String)
+				if err != nil {
+					return reattachConfigs, fmt.Errorf("Invalid TCP address %q for %q: %w", c.Addr.String, p, err)
+				}
+			default:
+				return reattachConfigs, fmt.Errorf("Unknown address type %q for %q", c.Addr.String, p)
+			}
+			reattachConfigs[p] = &goplugin.ReattachConfig{
+				Protocol:        goplugin.Protocol(c.Protocol),
+				ProtocolVersion: c.ProtocolVersion,
+				Pid:             c.Pid,
+				Test:            c.Test,
+				Addr:            addr,
+			}
+		}
+	}
+	return reattachConfigs, nil
+}
+
 // operationNoDataFunc is the function type for operations that are
 // executed without data downloaded.
 type operationNoDataFunc func(*Runner, context.Context, hclog.Logger, *pb.Job) (*pb.Job_Result, error)
