@@ -422,7 +422,7 @@ func (op *appOperation) dbPut(
 		}
 
 		// Next, ensure that the fields we want to match are matched.
-		matchFields := []string{"Sequence"}
+		matchFields := []string{"Generation", "Sequence"}
 		for _, name := range matchFields {
 			f := op.valueFieldReflect(value, name)
 			if !f.IsValid() {
@@ -438,12 +438,53 @@ func (op *appOperation) dbPut(
 		}
 	}
 
-	// If we're not updating, then set the sequence number up if we have one.
 	if !update {
+		// If we're not updating, then set the sequence number up if we have one.
+		var seq uint64
 		if f := op.valueFieldReflect(value, "Sequence"); f.IsValid() {
-			seq := atomic.AddUint64(op.appSeq(appRef), 1)
+			seq = atomic.AddUint64(op.appSeq(appRef), 1)
 			f.Set(reflect.ValueOf(seq))
 		}
+
+		if f := op.valueFieldReflect(value, "Generation"); f.IsValid() {
+			gen := f.Interface().(*pb.Generation)
+
+			// Default the generation to a new ULID if it isn't set.
+			if gen == nil || gen.Id == "" {
+				v, err := ulid()
+				if err != nil {
+					return err
+				}
+
+				gen = &pb.Generation{Id: v}
+				f.Set(reflect.ValueOf(gen))
+			}
+
+			// Our initial sequence is always our current to start. But
+			// if we can find an older version, we will update it.
+			gen.InitialSequence = seq
+
+			// Set our initial sequence number by searching the history
+			// to the first operation that used this generation.
+			iter, err := memTxn.LowerBound(
+				op.memTableName(),
+				opGenIndexName,
+				appRef.Project,
+				appRef.Application,
+				gen.Id,
+				uint64(0),
+			)
+			if err != nil {
+				return err
+			}
+			if raw := iter.Next(); raw != nil {
+				idx := raw.(*operationIndexRecord)
+				if idx.MatchRef(appRef) &&
+					idx.Generation == gen.Id {
+					gen.InitialSequence = idx.Sequence
+				}
+			}
+		}
 	}
 
 	// If there is a preload field, we want to set that to nil.
@@ -582,6 +623,11 @@ func (op *appOperation) indexPut(
 		sequence = v.(uint64)
 	}
 
+	var generation string
+	if v := op.valueField(value, "Generation"); v != nil && v.(*pb.Generation) != nil {
+		generation = v.(*pb.Generation).Id
+	}
+
 	// Get our refs
 	ref := op.valueField(value, "Application").(*pb.Ref_Application)
 	wsRef := op.valueField(value, "Workspace").(*pb.Ref_Workspace)
@@ -592,6 +638,7 @@ func (op *appOperation) indexPut(
 		App:          ref.Application,
 		Workspace:    wsRef.Workspace,
 		Sequence:     sequence,
+		Generation:   generation,
 		StartTime:    startTime,
 		CompleteTime: completeTime,
 	}
@@ -738,6 +785,38 @@ func (op *appOperation) memSchema() *memdb.TableSchema {
 					},
 				},
 			},
+
+			opGenIndexName: {
+				Name:   opGenIndexName,
+				Unique: false,
+
+				// Allow missing since not every app operation has a
+				// generation field.
+				AllowMissing: true,
+
+				Indexer: &memdb.CompoundIndex{
+					Indexes: []memdb.Indexer{
+						&memdb.StringFieldIndex{
+							Field:     "Project",
+							Lowercase: true,
+						},
+
+						&memdb.StringFieldIndex{
+							Field:     "App",
+							Lowercase: true,
+						},
+
+						&memdb.StringFieldIndex{
+							Field:     "Generation",
+							Lowercase: true,
+						},
+
+						&memdb.UintFieldIndex{
+							Field: "Sequence",
+						},
+					},
+				},
+			},
 		},
 	}
 }
@@ -750,6 +829,7 @@ type operationIndexRecord struct {
 	App          string
 	Workspace    string
 	Sequence     uint64
+	Generation   string
 	StartTime    time.Time
 	CompleteTime time.Time
 }
@@ -766,6 +846,7 @@ const (
 	opStartTimeIndexName    = "start-time"    // start time index
 	opCompleteTimeIndexName = "complete-time" // complete time index
 	opSeqIndexName          = "seq"           // sequence number index
+	opGenIndexName          = "generation"    // generation index
 )
 
 // listOperationsOptions are options that can be set for List calls on
