@@ -1,52 +1,49 @@
 import Route from '@ember/routing/route';
 import { inject as service } from '@ember/service';
 import ApiService from 'waypoint/services/api';
-import { Ref, Deployment, Build, Release, Project, StatusReport } from 'waypoint-pb';
+import { Ref, Deployment, Build, Release, Project, StatusReport, PushedArtifact } from 'waypoint-pb';
 import PollModelService from 'waypoint/services/poll-model';
-import ObjectProxy from '@ember/object/proxy';
-import PromiseProxyMixin from '@ember/object/promise-proxy-mixin';
-import { resolve, hash } from 'rsvp';
+import { hash } from 'rsvp';
+import { Breadcrumb } from 'waypoint/services/breadcrumbs';
 
-interface AppModelParams {
+export interface Params {
   app_id: string;
 }
 
-export interface AppRouteModel {
-  application: Ref.Application.AsObject;
-  deployments: Promise<Deployment.AsObject[]>;
-  releases: Promise<Release.AsObject[]>;
-  builds: Promise<Build.AsObject[]>;
-  statusReports: Promise<StatusReport.AsObject[]>;
-}
-
-interface WithStatusReport {
-  statusReport: StatusReport.AsObject;
-}
-
-export interface ResolvedModel {
+export interface Model {
   application: Ref.Application.AsObject;
   deployments: (Deployment.AsObject & WithStatusReport)[];
   releases: (Release.AsObject & WithStatusReport)[];
-  builds: (Build.AsObject & WithStatusReport)[];
+  builds: (Build.AsObject & WithPushedArtifact)[];
+  pushedArtifacts: PushedArtifact.AsObject[];
   statusReports: StatusReport.AsObject[];
 }
 
+interface WithStatusReport {
+  statusReport?: StatusReport.AsObject;
+}
+
+interface WithPushedArtifact {
+  pushedArtifact?: PushedArtifact.AsObject;
+}
+
 export default class App extends Route {
   @service api!: ApiService;
   @service pollModel!: PollModelService;
 
-  breadcrumbs(model: AppRouteModel) {
+  breadcrumbs(model: Model): Breadcrumb[] {
     if (!model) return [];
+
     return [
       {
-        label: model.application.project!,
+        label: model.application.project,
         icon: 'folder-outline',
-        args: ['workspace.projects.project.apps'],
+        route: 'workspace.projects.project.apps',
       },
     ];
   }
 
-  async model(params: AppModelParams): Promise<AppRouteModel> {
+  async model(params: Params): Promise<Model> {
     let ws = this.modelFor('workspace') as Ref.Workspace.AsObject;
     let wsRef = new Ref.Workspace();
     wsRef.setWorkspace(ws.workspace);
@@ -58,35 +55,24 @@ export default class App extends Route {
     appRef.setApplication(params.app_id);
     appRef.setProject(proj.name);
 
-    let ObjectPromiseProxy = ObjectProxy.extend(PromiseProxyMixin);
-
     return hash({
       application: appRef.toObject(),
-      deployments: ObjectPromiseProxy.create({
-        promise: resolve(this.api.listDeployments(wsRef, appRef)),
-      }),
-      releases: ObjectPromiseProxy.create({
-        promise: resolve(this.api.listReleases(wsRef, appRef)),
-      }),
-      builds: ObjectPromiseProxy.create({
-        promise: resolve(this.api.listBuilds(wsRef, appRef)),
-      }),
-      statusReports: ObjectPromiseProxy.create({
-        promise: resolve(this.api.listStatusReports(wsRef, appRef)),
-      }),
-      latestStatusReport: ObjectPromiseProxy.create({
-        promise: resolve(this.api.getLatestStatusReport(wsRef, appRef)),
-      }),
+      deployments: this.api.listDeployments(wsRef, appRef),
+      releases: this.api.listReleases(wsRef, appRef),
+      builds: this.api.listBuilds(wsRef, appRef),
+      pushedArtifacts: this.api.listPushedArtifacts(wsRef, appRef),
+      statusReports: this.api.listStatusReports(wsRef, appRef),
     });
   }
 
-  afterModel(model: ResolvedModel): void {
+  afterModel(model: Model): void {
     injectStatusReports(model);
+    injectPushedArtifacts(model);
     this.pollModel.setup(this);
   }
 }
 
-function injectStatusReports(model: ResolvedModel): void {
+function injectStatusReports(model: Model): void {
   let { deployments, releases, statusReports } = model;
 
   for (let statusReport of statusReports) {
@@ -103,3 +89,16 @@ function injectStatusReports(model: ResolvedModel): void {
     }
   }
 }
+
+function injectPushedArtifacts(model: Model): void {
+  let { builds, pushedArtifacts } = model;
+
+  for (let pushedArtifact of pushedArtifacts) {
+    if (pushedArtifact.buildId) {
+      let build = builds.find((b) => b.id === pushedArtifact.buildId);
+      if (build) {
+        build.pushedArtifact = pushedArtifact;
+      }
+    }
+  }
+}
