@@ -19,6 +19,8 @@ import {
   ListStatusReportsRequest,
   ListStatusReportsResponse,
   GetLatestStatusReportRequest,
+  ListPushedArtifactsRequest,
+  PushedArtifact,
 } from 'waypoint-pb';
 import config from 'waypoint/config/environment';
 
@@ -84,6 +86,25 @@ export default class ApiService extends Service {
     return resp.getBuildsList().map((d) => d.toObject());
   }
 
+  async listPushedArtifacts(
+    wsRef: Ref.Workspace,
+    appRef: Ref.Application
+  ): Promise<PushedArtifact.AsObject[]> {
+    let request = new ListPushedArtifactsRequest();
+
+    request.setApplication(appRef);
+    request.setWorkspace(wsRef);
+
+    // TODO(jgwhite): request.setIncludeBuild
+    // TODO(jgwhite): request.setOrder
+    // TODO(jgwhite): request.setStatusList
+
+    let response = await this.client.listPushedArtifacts(request, this.WithMeta());
+    let result = response.getArtifactsList().map((pa) => pa.toObject());
+
+    return result;
+  }
+
   async listReleases(wsRef: Ref.Workspace, appRef: Ref.Application): Promise<Release.AsObject[]> {
     let req = new ListReleasesRequest();
     req.setWorkspace(wsRef);
@@ -113,7 +134,10 @@ export default class ApiService extends Service {
     return resp.getStatusReportsList().map((d) => d.toObject());
   }
 
-  async getLatestStatusReport(wsRef: Ref.Workspace, appRef: Ref.Application): Promise<StatusReport|undefined>{
+  async getLatestStatusReport(
+    _wsRef: Ref.Workspace,
+    appRef: Ref.Application
+  ): Promise<StatusReport | undefined> {
     let req = new GetLatestStatusReportRequest();
     req.setApplication(appRef);
     // We have to try/catch to avoid failing the hash request because the api errors if no statusReport is available
