@@ -12,8 +12,10 @@ import * as release from './services/release';
 import * as versionInfo from './services/version-info';
 import * as statusReport from './services/status-report';
 import * as job from './services/job';
+import * as log from './services/log';
+import * as pushedArtifact from './services/pushed-artifact';
 
-export default function (this: Server) {
+export default function (this: Server): void {
   this.namespace = 'hashicorp.waypoint.Waypoint';
   this.urlPrefix = '/grpc';
   this.timing = 0;
@@ -45,6 +47,8 @@ export default function (this: Server) {
   this.post('/ListStatusReports', statusReport.list);
   this.post('/GetLatestStatusReport', statusReport.getLatest);
   this.post('/GetJobStream', job.stream);
+  this.post('/GetLogStream', log.stream);
+  this.post('/ListPushedArtifacts', pushedArtifact.list);
 
   if (!Ember.testing) {
     // Pass through all other requests
