@@ -58,6 +58,7 @@ export default Factory.extend({
         sequence: 3,
         application,
         deployment: deployments[2],
+        statusReport: server.create('status-report', 'ready', { application }),
       });
       server.create('release', 'random', 'hours-old-success', {
         sequence: 2,
@@ -83,30 +84,37 @@ export default Factory.extend({
         server.create('build', 'docker', 'days-old-success', {
           application,
           sequence: 1,
+          pushedArtifact: server.create('pushed-artifact', 'docker', 'days-old-success'),
         }),
         server.create('build', 'docker', 'days-old-success', {
           application,
           sequence: 2,
+          pushedArtifact: server.create('pushed-artifact', 'docker', 'days-old-success'),
         }),
         server.create('build', 'docker', 'hours-old-success', {
           application,
           sequence: 3,
+          pushedArtifact: server.create('pushed-artifact', 'docker', 'hours-old-success'),
         }),
         server.create('build', 'docker', 'hours-old-success', {
           application,
           sequence: 4,
+          pushedArtifact: server.create('pushed-artifact', 'docker', 'hours-old-success'),
         }),
         server.create('build', 'docker', 'minutes-old-success', {
           application,
           sequence: 5,
+          pushedArtifact: server.create('pushed-artifact', 'docker', 'minutes-old-success'),
         }),
         server.create('build', 'docker', 'minutes-old-success', {
           application,
           sequence: 6,
+          pushedArtifact: server.create('pushed-artifact', 'docker', 'minutes-old-success'),
         }),
         server.create('build', 'docker', 'seconds-old-success', {
           application,
           sequence: 7,
+          pushedArtifact: server.create('pushed-artifact', 'docker', 'seconds-old-success'),
         }),
       ];
 
@@ -174,4 +182,39 @@ export default Factory.extend({
       });
     },
   }),
+
+  'example-nodejs': trait({
+    name: 'example-nodejs',
+
+    afterCreate(project, server) {
+      let application = server.create('application', { name: 'example-nodejs', project });
+
+      server.create('build', 'pack', 'minutes-old-success', { application, sequence: 1 });
+      server.create('build', 'pack', 'seconds-old-success', { application, sequence: 2 });
+
+      server.create('deployment', 'docker', 'minutes-old-success', {
+        application,
+        sequence: 1,
+        statusReport: server.create('status-report', 'ready', { application }),
+        deployUrl: `https://instantly-worthy-shrew--v1.waypoint.run`,
+      });
+      server.create('deployment', 'docker', 'seconds-old-success', {
+        application,
+        sequence: 2,
+        statusReport: server.create('status-report', 'ready', { application }),
+        deployUrl: `https://instantly-worthy-shrew--v2.waypoint.run`,
+      });
+
+      server.create('release', 'docker', 'minutes-old-success', {
+        application,
+        sequence: 1,
+        statusReport: server.create('status-report', 'ready', { application }),
+      });
+      server.create('release', 'docker', 'seconds-old-success', {
+        application,
+        sequence: 2,
+        statusReport: server.create('status-report', 'ready', { application }),
+      });
+    },
+  }),
 });
