@@ -27,4 +27,18 @@ module('Acceptance | releases list', function (hooks) {
     assert.equal(page.list.length, 3);
     assert.equal(currentURL(), url);
   });
+
+  test('status reports appear where available', async function (assert) {
+    let project = this.server.create('project', { name: 'microchip' });
+    let application = this.server.create('application', { name: 'wp-bandwidth', project });
+    this.server.create('release', 'random', {
+      application,
+      sequence: 1,
+      statusReport: this.server.create('status-report', 'ready', { application }),
+    });
+
+    await page.visit();
+
+    assert.dom('[data-test-release-list] [data-test-status-report-indicator="ready"]').exists();
+  });
 });
