@@ -4,11 +4,6 @@ import Link from 'next/link'
 import subnavItems from 'data/navigation'
 import { productSlug } from 'data/metadata'
 
-// A regex to match the pathname that comes out of router.pathname
-// when the path is a content page (e.g. /docs/[[...page]]) to strip
-// out the part that we're not interested in.
-const multipathRegex = /\/\[\[.*\]\]/g
-
 export default function ProductSubnav() {
   const router = useRouter()
   return (
@@ -27,7 +22,7 @@ export default function ProductSubnav() {
           url: '/downloads',
         },
       ]}
-      currentPath={router.pathname.replace(multipathRegex, '')}
+      currentPath={router.asPath}
       menuItemsAlign="right"
       menuItems={subnavItems}
       constrainWidth
